@@ -14,11 +14,11 @@ __email__ = ""
 __status__ = "Development"
 
 import os
-import os.path
+import sys
+from os.path import join, normcase, exists, normpath
 from cbm.utils import config, update
 from pkg_resources import get_distribution, DistributionNotFound
 
-import sys
 if sys.version_info < (3, 6):
     print("Not supoted python version, cbm needs python version > 3.6")
     sys.exit()
@@ -26,9 +26,9 @@ if sys.version_info < (3, 6):
 try:
     _dist = get_distribution('cbm')
     # Normalize case for Windows systems
-    dist_loc = os.path.normcase(_dist.location)
-    here = os.path.normcase(__file__)
-    if not here.startswith(os.path.join(dist_loc, 'cbm')):
+    dist_loc = normcase(_dist.location)
+    here = normcase(__file__)
+    if not here.startswith(normpath(join(dist_loc, 'cbm'))):
         # not installed, but there is another version that *is*
         raise DistributionNotFound
 except DistributionNotFound:
@@ -39,11 +39,31 @@ else:
 paths = config.get_value(['paths'])
 for p in paths:
     try:
-        if not os.path.exists(os.path.join(config.path_work, paths[p])):
-            os.makedirs(os.path.join(config.path_work, paths[p]))
+        if not exists(normpath(join(config.path_work, paths[p]))):
+            os.makedirs(normpath(join(config.path_work, paths[p])))
             print(f"Directory {p} created successfully")
     except OSError as err:
         print(f"Directory {p} can not be created: ", err)
 
 config.create()
 update.check()
+
+
+def chip_images(*args):
+    from cbm.show import chip_images
+    return chip_images.main(*args)
+
+
+def background(*args):
+    from cbm.show import background
+    return background.main(*args)
+
+
+def time_series(*args):
+    from cbm.show import time_series
+    return time_series.main(*args)
+
+
+def calendar(*args):
+    from cbm.show import calendar
+    return calendar.main(*args)
