@@ -7,11 +7,11 @@
 # Copyright : 2021 European Commission, Joint Research Centre
 # License   : 3-Clause BSD
 import os
-import os.path
 import json
+from os.path import join, normpath, exists, isfile
 
 from cbm.sources import api
-from cbm.utils import spatial, config
+from cbm.utils import spatial_utils, config
 
 
 def by_location(aoi, year, lon, lat, chipsize=512, extend=512,
@@ -22,7 +22,7 @@ def by_location(aoi, year, lon, lat, chipsize=512, extend=512,
     Examples:
         from cbm.view import background
         background.by_location(aoi, year, lon, lat, 512, 512, 'Google',
-                                'temp/test.tif', True)
+                                True, True)
 
     Arguments:
         aoi, the area of interest e.g.: es, nld (str)
@@ -33,18 +33,20 @@ def by_location(aoi, year, lon, lat, chipsize=512, extend=512,
         tms, tile map server Google or Bing (str).
         quiet, print or not procedure information (Boolean).
     """
+
     json_data = json.loads(api.ploc(aoi, year, lon, lat, True))
     if type(json_data['ogc_fid']) is list:
         pid = json_data['ogc_fid'][0]
     else:
         pid = json_data['ogc_fid']
 
-    workdir = config.get_value(['paths', 'temp'])
-    path = f'{workdir}{aoi}{year}/{pid}/'
-    if not os.path.exists(path):
-        os.makedirs(path)
-    if not os.path.isfile(f"{path}info.json"):
-        with open(f'{path}info.json', "w") as f:
+    workdir = normpath(join(config.get_value(['paths', 'temp']),
+                            f'{aoi}{str(year)}', str(pid)))
+    json_file = normpath(join(workdir, 'info.json'))
+    if not exists(workdir):
+        os.makedirs(workdir)
+    if not isfile(json_file):
+        with open(json_file, "w") as f:
             json.dump(json_data, f)
 
     by_pid(aoi, year, pid, chipsize, extend, tms, quiet, axis)
@@ -58,7 +60,7 @@ def by_pid(aoi, year, pid, chipsize=512, extend=512,
     Examples:
         from cbm.view import background
         background.by_location(aoi, year, lon, lat, 512, 512, 'Google',
-                                'temp/test.tif', True)
+                                True, True)
 
     Arguments:
         aoi, the area of interest e.g.: es, nld (str)
@@ -68,23 +70,24 @@ def by_pid(aoi, year, pid, chipsize=512, extend=512,
         extend, size of the chip in meters  (float).
         tms, tile map server Google or Bing (str).
         quiet, print or not procedure information (Boolean).
-
     """
-    workdir = config.get_value(['paths', 'temp'])
-    path = f'{workdir}{aoi}{year}/{pid}/'
-    if not os.path.isfile(f"{path}info.json"):
-        json_data = json.loads(api.pid(aoi, year, pid, True))
-        if not os.path.exists(path):
-            os.makedirs(path)
 
-        with open(f'{path}info.json', "w") as f:
+    workdir = normpath(join(config.get_value(['paths', 'temp']),
+                            f'{aoi}{str(year)}', str(pid)))
+    json_file = normpath(join(workdir, 'info.json'))
+    if not isfile(json_file):
+        json_data = json.loads(api.pid(aoi, year, pid, True))
+        if not exists(workdir):
+            os.makedirs(workdir)
+
+        with open(json_file, "w") as f:
             json.dump(json_data, f)
     else:
-        with open(f"{path}info.json", 'r') as f:
+        with open(json_file, 'r') as f:
             json_data = json.load(f)
 
-    lat, lon = spatial.centroid(
-        spatial.transform_geometry(json_data))
+    lat, lon = spatial_utils.centroid(
+        spatial_utils.transform_geometry(json_data))
 
     api.background(lon, lat, chipsize, extend,
                    tms, aoi, year, pid, quiet)
