@@ -9,15 +9,18 @@
 
 
 # Get parcels data
+import os
 import json
 import datetime
+import pandas as pd
+from os.path import join, normpath, dirname
 from IPython.display import display
 from ipywidgets import (Text, Textarea, Label, HBox, VBox, Dropdown,
                         ToggleButtons, ToggleButton, Layout, Output,
                         Button, DatePicker, RadioButtons, IntSlider,
                         Box, HTML, SelectMultiple)
 
-from cbm.utils import data_handler, config, data_options
+from cbm.utils import config, data_options
 from cbm.ipycbm.ipy_get import get_maps
 
 
@@ -104,8 +107,16 @@ def get():
         if values['set']['data_source'] == 'api':
             get_requests = data_source()
             available_options = json.loads(get_requests.get_options())
-            outlog(data_handler.export(available_options,
-                                       10, f"{config.path_conf}api_options"))
+            try:
+                api_options = normpath(join(config.path_conf,
+                                            'api_options.json'))
+                os.makedirs(dirname(api_options), exist_ok=True)
+                with open(api_options, "w") as f:
+                    json.dump(available_options, f)
+                outlog(f"File saved at: {api_options}")
+            except Exception as err:
+                outlog(f"Could not create the file 'api_options.json': {err}")
+
             outlog(f"The API options are updated.")
         aois.options = tuple(aois_options())
         year.options = aois_years()[aois.value]
@@ -192,7 +203,8 @@ def get():
                 outlog_poly(
                     f"'{len(polyids['ogc_fid'])}' parcels where found:")
                 outlog_poly(polyids['ogc_fid'])
-                file = config.get_value(['files', 'pids_poly'])
+                file = normpath(join(config.get_value(['paths', 'temp']),
+                                     'pids_from_polygon.txt'))
                 with open(file, "w") as text_file:
                     text_file.write('\n'.join(map(str, polyids['ogc_fid'])))
             except Exception as err:
@@ -208,12 +220,12 @@ def get():
             elif obj['new'] == 2:
                 display(wbox_pids)
             elif obj['new'] == 3:
-                display(get_maps.base_map(aois.value,
-                                          config.get_value(['set', 'data_source'])))
+                display(get_maps.base_map(
+                    aois.value, config.get_value(['set', 'data_source'])))
             elif obj['new'] == 4:
-                display(VBox([get_maps.polygon(aois.value,
-                                               config.get_value(['set', 'data_source'])),
-                              get_ids_box, ppoly_out]))
+                display(VBox([get_maps.polygon(aois.value, config.get_value(
+                        ['set', 'data_source'])),
+                    get_ids_box, ppoly_out]))
 
     method.observe(method_options, 'value')
 
@@ -406,13 +418,19 @@ def get():
         pid = parcel['ogc_fid'][0]
         source = config.get_value(['set', 'data_source'])
         if source == 'api':
-            datapath = f'{paths.value}{aois.value}{year.value}/{pid}/'
+            datapath = normpath(
+                join(paths.value, f'{aois.value}{year.value}', str(pid)))
         elif source == 'direct':
             dataset = config.get_value(['set', 'dataset'])
-            datapath = f'{paths.value}{dataset}/{pid}/'
-        file_pinf = f"{datapath}info"
-
-        outlog(data_handler.export(parcel, 10, file_pinf))
+            datapath = normpath(join(paths.value, dataset, str(pid)))
+        file_pinf = normpath(join(datapath, 'info.json'))
+        try:
+            os.makedirs(dirname(file_pinf), exist_ok=True)
+            with open(file_pinf, "w") as f:
+                json.dump(parcel, f)
+            outlog(f"File saved at: {file_pinf}")
+        except Exception as err:
+            outlog(f"Could not create the file 'api_options.json': {err}")
 
         if pts_bt.value is True:
             outlog(f"Getting time series for parcel: '{pid}',",
@@ -424,16 +442,27 @@ def get():
                 band = ''
                 if pts_band.value != '':
                     band = f"_{pts_band.value}"
-                file_ts = f"{datapath}time_series_{pts}{band}"
-                outlog(data_handler.export(ts, 11, file_ts))
+                file_ts = normpath(join(datapath,
+                                        f'time_series_{pts}{band}.csv'))
+                try:
+                    if isinstance(ts, pd.DataFrame):
+                        ts.to_csv(file_ts, index=True, header=True)
+                    elif isinstance(ts, dict):
+                        os.makedirs(os.path.dirname(file_ts), exist_ok=True)
+                        df = pd.DataFrame.from_dict(ts, orient='columns')
+                        df.to_csv(file_ts, index=True, header=True)
+                    return f"File saved at: {file_ts}"
+                except Exception as err:
+                    return f"Could not create the file: {err}"
         if pci_bt.value is True:
-            files_pci = f"{datapath}chip_images/"
+            files_pci = normpath(join(datapath, 'chip_images'))
             outlog(f"Getting '{pci_band.value}' chip images for parcel: {pid}")
             with progress:
                 get_requests.rcbl(parcel, pci_start_date.value,
                                   pci_end_date.value, pci_band.value,
                                   pci_chipsize.value, files_pci)
-            filet = f'{datapath}/chip_images/images_list.{pci_band.value[0]}.csv'
+            filet = normpath(join(datapath, 'chip_images',
+                                  f'images_list.{pci_band.value[0]}.csv'))
             if file_len(filet) > 1:
                 outlog(f"Completed, all GeoTIFFs for bands '{pci_band.value}' are ",
                        f"downloaded in the folder: '{datapath}/chip_images'")
@@ -457,8 +486,7 @@ def get():
         outlog(f"Getting parcels information for: '{pids}'")
         for pid in pids:
             try:
-                parcel = json.loads(get_requests.pid(aois.value,
-                                                     year.value,
+                parcel = json.loads(get_requests.pid(aois.value, year.value,
                                                      pid, True))
                 get_data(parcel)
             except Exception as err:
@@ -473,8 +501,8 @@ def get():
                     lon, lat = plon.value, plat.value
                     get_from_location(lon, lat)
             except Exception as err:
-                outlog(
-                    f"Could not get parcel information for location '{lon}', '{lat}': {err}")
+                outlog("Could not get parcel information for location",
+                       f"'{lon}', '{lat}': {err}")
 
         elif method.value == 2:
             try:
@@ -495,7 +523,8 @@ def get():
         elif method.value == 4:
             try:
                 plimit = int(values['set']['plimit'])
-                file = config.get_value(['files', 'pids_poly'])
+                file = normpath(join(config.get_value(['paths', 'temp']),
+                                     'pids_from_polygon.txt'))
                 with open(file, "r") as text_file:
                     pids = text_file.read().split('\n')
                 outlog("Geting data form the parcels:")
